/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_PErUpu7o);
  numBytes += sLine_init(&sLine_OYCgfY5B);
  numBytes += sLine_init(&sLine_WP03lwbU);
  numBytes += sLine_init(&sLine_tVqPKjA8);
  numBytes += sLine_init(&sLine_en9kzWB2);
  numBytes += sBiquad_init(&sBiquad_s_sgijKl8m);
  numBytes += sLine_init(&sLine_aoNhaAGT);
  numBytes += sLine_init(&sLine_241gE8Y5);
  numBytes += sLine_init(&sLine_I7xPserz);
  numBytes += sLine_init(&sLine_wLm86jBE);
  numBytes += sBiquad_init(&sBiquad_s_vkIdo3oW);
  numBytes += sLine_init(&sLine_HDcwM5pp);
  numBytes += sLine_init(&sLine_xxpgAHg5);
  numBytes += sLine_init(&sLine_qeV0ph8R);
  numBytes += sLine_init(&sLine_iy83qzck);
  numBytes += sLine_init(&sLine_Z2iwXVA0);
  numBytes += sBiquad_init(&sBiquad_s_Pg9bK5mN);
  numBytes += sLine_init(&sLine_kZjIo213);
  numBytes += sLine_init(&sLine_j72hrAf6);
  numBytes += sLine_init(&sLine_IjAwriQ8);
  numBytes += sLine_init(&sLine_pIyTGL3T);
  numBytes += sLine_init(&sLine_UH8WPBZy);
  numBytes += sBiquad_init(&sBiquad_s_Y9UKW6gQ);
  numBytes += sLine_init(&sLine_duuyj0N7);
  numBytes += sLine_init(&sLine_3XIEhzcA);
  numBytes += sLine_init(&sLine_PnTbt9HP);
  numBytes += sLine_init(&sLine_SEf7LQjZ);
  numBytes += sBiquad_init(&sBiquad_s_bTalbYXB);
  numBytes += sLine_init(&sLine_nkTlH7mu);
  numBytes += sLine_init(&sLine_KH0KJZJb);
  numBytes += sLine_init(&sLine_zAnt6Y21);
  numBytes += sLine_init(&sLine_C89W0Wa5);
  numBytes += sLine_init(&sLine_4tAFxdz2);
  numBytes += sBiquad_init(&sBiquad_s_iwzq1l1B);
  numBytes += cVar_init_f(&cVar_tK2MQf97, 0.0f);
  numBytes += cVar_init_f(&cVar_m16UbkiZ, 0.0f);
  numBytes += cVar_init_f(&cVar_Vr9aljDN, 0.0f);
  numBytes += cVar_init_f(&cVar_SwEErfxM, 0.0f);
  numBytes += cSlice_init(&cSlice_Kt9cxhkN, 1, -1);
  numBytes += cVar_init_f(&cVar_JJ3omtDP, 1337.0f);
  numBytes += cVar_init_f(&cVar_o1kr1i2D, 0.0f);
  numBytes += cIf_init(&cIf_XzP0eDoc, false);
  numBytes += cIf_init(&cIf_xpnoi1p3, false);
  numBytes += cBinop_init(&cBinop_qBx1C9bs, 0.0f); // __pow
  numBytes += cIf_init(&cIf_yxj6KIvw, false);
  numBytes += cBinop_init(&cBinop_KHHnOs2r, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DyZoHxi7, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_EiW0ez3n, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_JcnpS2yf, 0.0f);
  numBytes += cIf_init(&cIf_68ZKFiDu, false);
  numBytes += cIf_init(&cIf_L7T8cgL7, false);
  numBytes += cBinop_init(&cBinop_6ohddKZP, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Rf27qFTD, false);
  numBytes += cBinop_init(&cBinop_kB3LEl3G, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_JHFCeH9f, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Ath67Uvk, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_fP4bpw4b, 0.0f);
  numBytes += cIf_init(&cIf_yo8eWbnx, false);
  numBytes += cIf_init(&cIf_RXcKLSox, false);
  numBytes += cBinop_init(&cBinop_jiPHyxFK, 0.0f); // __pow
  numBytes += cIf_init(&cIf_CVprvZCZ, false);
  numBytes += cBinop_init(&cBinop_BEUUyipJ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_WhBT8ArO, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_S68OXJv4, -15.0f); // __eq
  numBytes += cIf_init(&cIf_mShKJJOU, false);
  numBytes += cSlice_init(&cSlice_mnoDEiqU, 1, -1);
  numBytes += cVar_init_f(&cVar_zeskSoJL, 0.0f);
  numBytes += cSlice_init(&cSlice_v4JRV6Cj, 1, -1);
  numBytes += cVar_init_f(&cVar_280zKExu, 0.0f);
  numBytes += cSlice_init(&cSlice_CHETUxWW, 1, -1);
  numBytes += cVar_init_f(&cVar_UDhhkaJT, 0.0f);
  numBytes += cSlice_init(&cSlice_fTmANkOk, 1, -1);
  numBytes += cVar_init_f(&cVar_CQpjVNNW, 0.313f);
  numBytes += cBinop_init(&cBinop_hIQB6UVu, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_bmgp0KZB, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_rf8i719E, 0.0f);
  numBytes += cVar_init_f(&cVar_jKsW4pVi, 1337.0f);
  numBytes += cVar_init_f(&cVar_JqKwWF2u, 0.3f);
  numBytes += cBinop_init(&cBinop_PRMYv0s2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jzcprtWk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_658NRPrs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DifUeMsZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DGFJppUs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ouNUQhZT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Lsfe2y9e, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_SxIsY4lh, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_fHCUExZK, 0.0f);
  numBytes += cVar_init_f(&cVar_5Dk7Jf5n, 1337.0f);
  numBytes += cVar_init_f(&cVar_hCbWpWXF, 0.313f);
  numBytes += cBinop_init(&cBinop_yF9ODYAM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V57AtSvS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_T5MnQNMp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ndm0dIfG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aqXHI191, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_h4aFXtvg, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_XJRrrdKn, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_WHD4fa6Z, 0.0f);
  numBytes += cVar_init_f(&cVar_O9yOlrcC, 1037.0f);
  numBytes += cVar_init_f(&cVar_inVAurtp, 0.4f);
  numBytes += cBinop_init(&cBinop_XEVProeF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rbMWmofp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FFsOIPvb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_C22fROfb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_e0hUK6oa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dCnfEdV4, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_u3FYnzD4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0U8nt119, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3S91fDi8, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_nvo0mJ6i, 1, -1);
  numBytes += cVar_init_f(&cVar_iJHitIXB, 1337.0f);
  numBytes += cVar_init_f(&cVar_89Xj94Bv, 0.0f);
  numBytes += cIf_init(&cIf_fsMEcMeN, false);
  numBytes += cIf_init(&cIf_wQpXqkKJ, false);
  numBytes += cBinop_init(&cBinop_HglamV2M, 0.0f); // __pow
  numBytes += cIf_init(&cIf_2W3vYrC2, false);
  numBytes += cBinop_init(&cBinop_h2ZtNq3o, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_TffqUw72, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Dyg1lYyV, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_XP5dB4JO, 0.0f);
  numBytes += cIf_init(&cIf_IRYxARRK, false);
  numBytes += cIf_init(&cIf_YpMz1zFf, false);
  numBytes += cBinop_init(&cBinop_B82fxOVw, 0.0f); // __pow
  numBytes += cIf_init(&cIf_TQJF6Sv2, false);
  numBytes += cBinop_init(&cBinop_A3hsjseo, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_xWfdlT2Z, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_17eid4Hl, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_sRNwaEk8, 0.0f);
  numBytes += cIf_init(&cIf_trEeQMO4, false);
  numBytes += cIf_init(&cIf_HIRUoQN1, false);
  numBytes += cBinop_init(&cBinop_qD2K8oDg, 0.0f); // __pow
  numBytes += cIf_init(&cIf_21vPJTZ1, false);
  numBytes += cBinop_init(&cBinop_fqxjQnV0, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_vfxlN3lS, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_mNIyDyHh, -15.0f); // __eq
  numBytes += cIf_init(&cIf_PdL6L7wD, false);
  numBytes += cSlice_init(&cSlice_FLlOfTNG, 1, -1);
  numBytes += cVar_init_f(&cVar_9N6OkI9I, 0.0f);
  numBytes += cSlice_init(&cSlice_IUzvHzKm, 1, -1);
  numBytes += cVar_init_f(&cVar_OtJgpkga, 0.0f);
  numBytes += cSlice_init(&cSlice_yysvLT5u, 1, -1);
  numBytes += cVar_init_f(&cVar_oMiSmdKG, 0.0f);
  numBytes += cSlice_init(&cSlice_QNdLL6qG, 1, -1);
  numBytes += cVar_init_f(&cVar_4z0uDaNC, 0.313f);
  numBytes += cBinop_init(&cBinop_yuImlq83, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_dSE6kqam, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Ci22RsRA, 0.0f);
  numBytes += cVar_init_f(&cVar_nzHbJGEY, 1337.0f);
  numBytes += cVar_init_f(&cVar_m7gdqJjz, 0.3f);
  numBytes += cBinop_init(&cBinop_a2xTOvVl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sSZoWdZ4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mIXYmlTX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iemFMUbP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vheTn3L7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1N3GXM6F, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6Qx4HmoG, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ir6jeCcz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_XYVXuw4x, 0.0f);
  numBytes += cVar_init_f(&cVar_THBfYb0x, 1337.0f);
  numBytes += cVar_init_f(&cVar_DAl9UZPl, 0.313f);
  numBytes += cBinop_init(&cBinop_dTY9Vl77, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_z1enPKWu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hq4kKqSH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BCr3AiLl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GnqC0Ke5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iGveYkW0, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_pfC6Mgtz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_wGp2aYHf, 0.0f);
  numBytes += cVar_init_f(&cVar_d0mBrJ3N, 1037.0f);
  numBytes += cVar_init_f(&cVar_tS9Qpmdc, 0.4f);
  numBytes += cBinop_init(&cBinop_NFGyI3C5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CcB4WaOT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ViRWhzIY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_U1qQMczF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jjXhYD5c, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Syct2vKt, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fR7uKXku, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_E8fIsxv0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JV3esKSG, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_WPa3JV8v, 5705.6f);
  numBytes += cVar_init_f(&cVar_N4tSbeiN, 313.3f);
  numBytes += cBinop_init(&cBinop_xhGgIH0b, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_QRguQUQj, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_dFWl0Vvy, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ASc99Wet_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MrpvwYBV_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DGhw8SBx_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_REFpn93v_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3eDnSN55_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fV6DJCOQ_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_onvAC7Hi_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iwA1XD8H_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ftUfc8GP_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZW26pAqm_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZNrqOr5m_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4WDzG9Q7_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bmRTsSt3_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xCsbnVhb_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U1do5K8s_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GI5QpUsr_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_np1xhTq6_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MsqV6TGU_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6FmlyAVu_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R0h0NINL_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aKdoaAEH_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TttfiG15_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_biDLiiWp_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kPAoGltt_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_seukyCPo_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3m7rg6PY_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZCgDDWBZ_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SRcJY6eB_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_81NCZFP6_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YB3PnFIL_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2qpmpWfN_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JsLqT4Uh_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X3bgaxio_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_tK2MQf97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KrjsgUyx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_m16UbkiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ccm48n17_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Vr9aljDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SlyoB26v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_SwEErfxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lhS5sZuK_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ZYvvrC0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IZ9kyi5w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qEXXPTnM_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_U3syuVIO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Kt9cxhkN, 0, m, &cSlice_Kt9cxhkN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_g0rz4Zhb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_Kt9cxhkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_30EZUDOL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_30EZUDOL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_JJ3omtDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_30EZUDOL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_30EZUDOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_onvAC7Hi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_o1kr1i2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_miS13GMt_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_XzP0eDoc, 0, m, &cIf_XzP0eDoc_sendMessage);
}

void Heavy_WSTD_3Q::cIf_XzP0eDoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wxVoZX0t_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_xpnoi1p3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_bAriKf7C_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_eg6eLQsz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_kjG2YTqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qBx1C9bs, HV_BINOP_POW, 0, m, &cBinop_qBx1C9bs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qBx1C9bs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yxj6KIvw, 0, m, &cIf_yxj6KIvw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MQ7ikFoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IxLzECFR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LhRCNQVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FBXcgl1E_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SUvu7c8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xpnoi1p3, 0, m, &cIf_xpnoi1p3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FBXcgl1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xpnoi1p3, 1, m, &cIf_xpnoi1p3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eg6eLQsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_MQ7ikFoT_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_bAriKf7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_yxj6KIvw, 0, m, &cIf_yxj6KIvw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IxLzECFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qBx1C9bs, HV_BINOP_POW, 1, m, &cBinop_qBx1C9bs_sendMessage);
  cMsg_kjG2YTqs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_yxj6KIvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_u3FYnzD4, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_miS13GMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XzP0eDoc, 1, m, &cIf_XzP0eDoc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wxVoZX0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DyZoHxi7, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DyZoHxi7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EiW0ez3n, HV_BINOP_EQ, 1, m, &cBinop_EiW0ez3n_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_iaakKBZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KHHnOs2r, HV_BINOP_ADD, 0, m, &cBinop_KHHnOs2r_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KHHnOs2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LhRCNQVR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SUvu7c8r_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DyZoHxi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yxj6KIvw, 1, m, &cIf_yxj6KIvw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EiW0ez3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IIhgwp82_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_IIhgwp82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_u3FYnzD4, m);
}

void Heavy_WSTD_3Q::cCast_qBsLuEsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KHHnOs2r, HV_BINOP_ADD, 1, m, &cBinop_KHHnOs2r_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DyZoHxi7, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DyZoHxi7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EiW0ez3n, HV_BINOP_EQ, 0, m, &cBinop_EiW0ez3n_sendMessage);
}

void Heavy_WSTD_3Q::cCast_svjvm15W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o1kr1i2D, 0, m, &cVar_o1kr1i2D_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0JBEEr15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iaakKBZL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_JcnpS2yf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KyvhlKgh_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_68ZKFiDu, 0, m, &cIf_68ZKFiDu_sendMessage);
}

void Heavy_WSTD_3Q::cIf_68ZKFiDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FY9x25YA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_L7T8cgL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ZNbYp7zD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_XnUKJNTr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_fwUQmdCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ohddKZP, HV_BINOP_POW, 0, m, &cBinop_6ohddKZP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6ohddKZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rf27qFTD, 0, m, &cIf_Rf27qFTD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zW0sXFW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_JAgBrUpC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_D1eCb6yI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L7T8cgL7, 0, m, &cIf_L7T8cgL7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_n3ootpLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_i9v20cln_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_i9v20cln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L7T8cgL7, 1, m, &cIf_L7T8cgL7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XnUKJNTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_zW0sXFW0_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZNbYp7zD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Rf27qFTD, 0, m, &cIf_Rf27qFTD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JAgBrUpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ohddKZP, HV_BINOP_POW, 1, m, &cBinop_6ohddKZP_sendMessage);
  cMsg_fwUQmdCH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_Rf27qFTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VJlDNA3O_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZrlP2U1t_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_GTEFrM5g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_KyvhlKgh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_68ZKFiDu, 1, m, &cIf_68ZKFiDu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FY9x25YA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JHFCeH9f, HV_BINOP_GREATER_THAN, 1, m, &cBinop_JHFCeH9f_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ath67Uvk, HV_BINOP_EQ, 1, m, &cBinop_Ath67Uvk_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_enYga11e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kB3LEl3G, HV_BINOP_ADD, 0, m, &cBinop_kB3LEl3G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kB3LEl3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n3ootpLU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D1eCb6yI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JHFCeH9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rf27qFTD, 1, m, &cIf_Rf27qFTD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ath67Uvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n4btGHgS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_n4btGHgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VJlDNA3O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZrlP2U1t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_GTEFrM5g_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QzOildlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_enYga11e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_Rv8RTwib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kB3LEl3G, HV_BINOP_ADD, 1, m, &cBinop_kB3LEl3G_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JHFCeH9f, HV_BINOP_GREATER_THAN, 0, m, &cBinop_JHFCeH9f_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ath67Uvk, HV_BINOP_EQ, 0, m, &cBinop_Ath67Uvk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dFCGQ0dR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JcnpS2yf, 0, m, &cVar_JcnpS2yf_sendMessage);
}

void Heavy_WSTD_3Q::cVar_fP4bpw4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lFrDjCKK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_yo8eWbnx, 0, m, &cIf_yo8eWbnx_sendMessage);
}

void Heavy_WSTD_3Q::cIf_yo8eWbnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_uoWzafDA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_RXcKLSox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_xAJJJ11C_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1HR26nks_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_Z7Sd5FkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jiPHyxFK, HV_BINOP_POW, 0, m, &cBinop_jiPHyxFK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jiPHyxFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CVprvZCZ, 0, m, &cIf_CVprvZCZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xvxdVWvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ddOUPR6l_sendMessage);
}

void Heavy_WSTD_3Q::cCast_f8LA52k4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RXcKLSox, 0, m, &cIf_RXcKLSox_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wFyKzwB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZjEkc84c_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZjEkc84c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RXcKLSox, 1, m, &cIf_RXcKLSox_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1HR26nks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_xvxdVWvP_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_xAJJJ11C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_CVprvZCZ, 0, m, &cIf_CVprvZCZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ddOUPR6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jiPHyxFK, HV_BINOP_POW, 1, m, &cBinop_jiPHyxFK_sendMessage);
  cMsg_Z7Sd5FkJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_CVprvZCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_3S91fDi8, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_lFrDjCKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yo8eWbnx, 1, m, &cIf_yo8eWbnx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uoWzafDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WhBT8ArO, HV_BINOP_GREATER_THAN, 1, m, &cBinop_WhBT8ArO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_S68OXJv4, HV_BINOP_EQ, 1, m, &cBinop_S68OXJv4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_7ywOLrke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BEUUyipJ, HV_BINOP_ADD, 0, m, &cBinop_BEUUyipJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BEUUyipJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wFyKzwB5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f8LA52k4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WhBT8ArO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CVprvZCZ, 1, m, &cIf_CVprvZCZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_S68OXJv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gCfDQHc0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_gCfDQHc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3S91fDi8, m);
}

void Heavy_WSTD_3Q::cCast_vhiEWnr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BEUUyipJ, HV_BINOP_ADD, 1, m, &cBinop_BEUUyipJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WhBT8ArO, HV_BINOP_GREATER_THAN, 0, m, &cBinop_WhBT8ArO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_S68OXJv4, HV_BINOP_EQ, 0, m, &cBinop_S68OXJv4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7weiZPK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fP4bpw4b, 0, m, &cVar_fP4bpw4b_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GT4yewcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7ywOLrke_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_mShKJJOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_0U8nt119, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_1c16vHKj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mnoDEiqU, 0, m, &cSlice_mnoDEiqU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xQieDjiO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_mnoDEiqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Nj4aBeR2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Nj4aBeR2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_zeskSoJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Nj4aBeR2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Nj4aBeR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3eDnSN55_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_xQieDjiO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_v4JRV6Cj, 0, m, &cSlice_v4JRV6Cj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_U3syuVIO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_v4JRV6Cj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7JcG8g33_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7JcG8g33_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_280zKExu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7JcG8g33_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_7JcG8g33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ftUfc8GP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_g0rz4Zhb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CHETUxWW, 0, m, &cSlice_CHETUxWW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_sn8jUT3q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_CHETUxWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5QvKatA9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5QvKatA9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_UDhhkaJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5QvKatA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_5QvKatA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fV6DJCOQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_sn8jUT3q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fTmANkOk, 0, m, &cSlice_fTmANkOk_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_fTmANkOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5m0iWNpl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5m0iWNpl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_CQpjVNNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5m0iWNpl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_5m0iWNpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iwA1XD8H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_XgAAFiNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PErUpu7o, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_oQgkAdi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OYCgfY5B, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_OcOlJPFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WP03lwbU, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_HReqdqkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tVqPKjA8, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_yqagEsTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_en9kzWB2, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_G6bM6WsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mckeGldL_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_mckeGldL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hIQB6UVu, HV_BINOP_DIVIDE, 1, m, &cBinop_hIQB6UVu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OzQVP6pF_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_jFXyWOAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ssd8KA3s_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_bv9a8UBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jFXyWOAz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ssd8KA3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hIQB6UVu, HV_BINOP_DIVIDE, 0, m, &cBinop_hIQB6UVu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OzQVP6pF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bv9a8UBp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_hIQB6UVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bmgp0KZB, HV_BINOP_MULTIPLY, 1, m, &cBinop_bmgp0KZB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bmgp0KZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YkfQOUz8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dkTHIbFs_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_ehXiINbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_N2ONmcU2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_Bn7hmXNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OcgNrlZq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_693BIMnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Ly4vIs2o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ly4vIs2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bmgp0KZB, HV_BINOP_MULTIPLY, 0, m, &cBinop_bmgp0KZB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wAfRgKT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_51xhG2JM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_51xhG2JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2YUHACMN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3nj8mCKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rf8i719E, 1, m, &cVar_rf8i719E_sendMessage);
}

void Heavy_WSTD_3Q::cVar_rf8i719E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MGDbifsN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_cAYJez3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jzcprtWk, HV_BINOP_MULTIPLY, 1, m, &cBinop_jzcprtWk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EsIxlgZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cAYJez3n_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vtIkOesH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_k2kyrWX7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k2kyrWX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_658NRPrs, HV_BINOP_MULTIPLY, 1, m, &cBinop_658NRPrs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OnEAWyDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DifUeMsZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_DifUeMsZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ox9i09yV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OnEAWyDJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ba046dJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DGFJppUs, HV_BINOP_MULTIPLY, 1, m, &cBinop_DGFJppUs_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_HMIeqZSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_loHxfPlq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_loHxfPlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ouNUQhZT, HV_BINOP_MULTIPLY, 1, m, &cBinop_ouNUQhZT_sendMessage);
}

void Heavy_WSTD_3Q::cVar_jKsW4pVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rNkIv95T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_693BIMnd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_igPPwIjz_sendMessage);
}

void Heavy_WSTD_3Q::cVar_JqKwWF2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wAfRgKT5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dkTHIbFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Bn7hmXNP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YkfQOUz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ehXiINbs_sendMessage);
}

void Heavy_WSTD_3Q::cSend_N2ONmcU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4WDzG9Q7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_OcgNrlZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZNrqOr5m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_XUYT9g8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZW26pAqm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_2YUHACMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FNSBg2F0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FNSBg2F0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PRMYv0s2, HV_BINOP_MULTIPLY, 1, m, &cBinop_PRMYv0s2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PRMYv0s2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Vg7bRnmx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Vg7bRnmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XUYT9g8f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_MGDbifsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7OkQEDr0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7OkQEDr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkMfYmMM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JnX5UseT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FTmXDctW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GLcjOUXR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1lRMm8a8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5bJhKI8P_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jzcprtWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XgAAFiNi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_658NRPrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oQgkAdi7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_DifUeMsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OcOlJPFA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_DGFJppUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HReqdqkb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ouNUQhZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yqagEsTh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_InKaoPwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jKsW4pVi, 0, m, &cVar_jKsW4pVi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DGTbXMUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JqKwWF2u, 1, m, &cVar_JqKwWF2u_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5bJhKI8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jzcprtWk, HV_BINOP_MULTIPLY, 0, m, &cBinop_jzcprtWk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nkMfYmMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_JnX5UseT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ouNUQhZT, HV_BINOP_MULTIPLY, 0, m, &cBinop_ouNUQhZT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1lRMm8a8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_658NRPrs, HV_BINOP_MULTIPLY, 0, m, &cBinop_658NRPrs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FTmXDctW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DGFJppUs, HV_BINOP_MULTIPLY, 0, m, &cBinop_DGFJppUs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GLcjOUXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DifUeMsZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_DifUeMsZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rNkIv95T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JqKwWF2u, 0, m, &cVar_JqKwWF2u_sendMessage);
}

void Heavy_WSTD_3Q::cCast_igPPwIjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rf8i719E, 0, m, &cVar_rf8i719E_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_uIVsbjvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aoNhaAGT, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_o5Sb7fBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_241gE8Y5, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_9Q8QhsOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I7xPserz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_W5NUHOlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wLm86jBE, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_UHHbUTPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QvHutuLd_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_QvHutuLd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lsfe2y9e, HV_BINOP_DIVIDE, 1, m, &cBinop_Lsfe2y9e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ddfi5wfs_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_a0qcWzK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_agFtjOUU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_dBwa4iXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_a0qcWzK9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_agFtjOUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lsfe2y9e, HV_BINOP_DIVIDE, 0, m, &cBinop_Lsfe2y9e_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ddfi5wfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dBwa4iXg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Lsfe2y9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SxIsY4lh, HV_BINOP_MULTIPLY, 1, m, &cBinop_SxIsY4lh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SxIsY4lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_11HZ300f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9GTzlG4C_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_DyUu6lGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NlmhgxO4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_9uwieH4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DIPUyGod_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3pRBABYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_r3F28ZPh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r3F28ZPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SxIsY4lh, HV_BINOP_MULTIPLY, 0, m, &cBinop_SxIsY4lh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mpdpdW8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_oOXsN0P5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oOXsN0P5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7qKOLPqz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MvQZsE3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T5MnQNMp, HV_BINOP_MULTIPLY, 1, m, &cBinop_T5MnQNMp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HXrWhtHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fHCUExZK, 1, m, &cVar_fHCUExZK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_c3RW78rM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ndm0dIfG, HV_BINOP_MULTIPLY, 1, m, &cBinop_ndm0dIfG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_TCsGDltG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0cu7eQar_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0cu7eQar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aqXHI191, HV_BINOP_MULTIPLY, 1, m, &cBinop_aqXHI191_sendMessage);
}

void Heavy_WSTD_3Q::cVar_fHCUExZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7fb1XiTP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_5Dk7Jf5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_26ZnxNPN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3pRBABYk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BxX6cZxl_sendMessage);
}

void Heavy_WSTD_3Q::cVar_hCbWpWXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_mpdpdW8j_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9GTzlG4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9uwieH4h_sendMessage);
}

void Heavy_WSTD_3Q::cCast_11HZ300f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_DyUu6lGd_sendMessage);
}

void Heavy_WSTD_3Q::cSend_NlmhgxO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_U1do5K8s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_DIPUyGod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xCsbnVhb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_g8zs44Tq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bmRTsSt3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_7qKOLPqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NUcfrnuH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NUcfrnuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yF9ODYAM, HV_BINOP_MULTIPLY, 1, m, &cBinop_yF9ODYAM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yF9ODYAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5lxZXa0L_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5lxZXa0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_g8zs44Tq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_7fb1XiTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ociOnVxX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ociOnVxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C23vP4Ar_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DwfxVtdk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HURrk88n_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ztTamNZI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_V57AtSvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uIVsbjvI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_T5MnQNMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o5Sb7fBK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ndm0dIfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Q8QhsOS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_aqXHI191_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W5NUHOlX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_hba0s3NV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hCbWpWXF, 1, m, &cVar_hCbWpWXF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Iw7wm7eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5Dk7Jf5n, 0, m, &cVar_5Dk7Jf5n_sendMessage);
}

void Heavy_WSTD_3Q::cCast_26ZnxNPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hCbWpWXF, 0, m, &cVar_hCbWpWXF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BxX6cZxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fHCUExZK, 0, m, &cVar_fHCUExZK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_C23vP4Ar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aqXHI191, HV_BINOP_MULTIPLY, 0, m, &cBinop_aqXHI191_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DwfxVtdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ndm0dIfG, HV_BINOP_MULTIPLY, 0, m, &cBinop_ndm0dIfG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HURrk88n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T5MnQNMp, HV_BINOP_MULTIPLY, 0, m, &cBinop_T5MnQNMp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ztTamNZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V57AtSvS, HV_BINOP_MULTIPLY, 0, m, &cBinop_V57AtSvS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_eZfkCh03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HDcwM5pp, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_tOPx4rRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xxpgAHg5, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_krYRJBXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qeV0ph8R, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_agJptyAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iy83qzck, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Lsa1Xnza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z2iwXVA0, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Ag5WbowL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PtgFbE7i_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_PtgFbE7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h4aFXtvg, HV_BINOP_DIVIDE, 1, m, &cBinop_h4aFXtvg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q1WWBaEu_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_qimlqoiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_xgbfH6jD_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_vdJ3KPgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_qimlqoiJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xgbfH6jD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h4aFXtvg, HV_BINOP_DIVIDE, 0, m, &cBinop_h4aFXtvg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Q1WWBaEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vdJ3KPgd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_h4aFXtvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XJRrrdKn, HV_BINOP_MULTIPLY, 1, m, &cBinop_XJRrrdKn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XJRrrdKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e1Lr5s37_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_clgNTA82_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_xZCr1yee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_h5Tv2Otj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_YixbhwI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XTg6LZ5J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_cEtP5r4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_sLYrTLWu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sLYrTLWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XJRrrdKn, HV_BINOP_MULTIPLY, 0, m, &cBinop_XJRrrdKn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YfvmYQB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_9C6lfgiZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9C6lfgiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IutSnfrE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lNaEJXUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rbMWmofp, HV_BINOP_MULTIPLY, 1, m, &cBinop_rbMWmofp_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_msWhHJcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3PiYZaIW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3PiYZaIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lNaEJXUA_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_BjifunOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_a33jdLMy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a33jdLMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FFsOIPvb, HV_BINOP_MULTIPLY, 1, m, &cBinop_FFsOIPvb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LU4eea6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C22fROfb, HV_BINOP_MULTIPLY, 1, m, &cBinop_C22fROfb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_NpRT4Oni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DdNAEwDB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DdNAEwDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LU4eea6z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fDd62fW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WHD4fa6Z, 1, m, &cVar_WHD4fa6Z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gEqWLPTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e0hUK6oa, HV_BINOP_MULTIPLY, 1, m, &cBinop_e0hUK6oa_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_cOUpU7KD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DGtGTs2x_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DGtGTs2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dCnfEdV4, HV_BINOP_MULTIPLY, 1, m, &cBinop_dCnfEdV4_sendMessage);
}

void Heavy_WSTD_3Q::cVar_WHD4fa6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iFuf31ur_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_O9yOlrcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LJJPGxpZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_cEtP5r4t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wklYDiXY_sendMessage);
}

void Heavy_WSTD_3Q::cVar_inVAurtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_YfvmYQB8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_e1Lr5s37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_xZCr1yee_sendMessage);
}

void Heavy_WSTD_3Q::cCast_clgNTA82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_YixbhwI3_sendMessage);
}

void Heavy_WSTD_3Q::cSend_h5Tv2Otj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MsqV6TGU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_XTg6LZ5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_np1xhTq6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_3jFGxn2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GI5QpUsr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_IutSnfrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_d7PlmPIN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_d7PlmPIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XEVProeF, HV_BINOP_MULTIPLY, 1, m, &cBinop_XEVProeF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XEVProeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Rw2qkUUs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Rw2qkUUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3jFGxn2t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_iFuf31ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Qny6K2jX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Qny6K2jX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dfatyEm1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sfkoRuFs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MbxNL5rq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tdKtNGqQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1Wowgf1C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PVlP3D21_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rbMWmofp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eZfkCh03_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FFsOIPvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tOPx4rRa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_C22fROfb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_krYRJBXB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_e0hUK6oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_agJptyAo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_dCnfEdV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lsa1Xnza_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_bTLMnZUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_O9yOlrcC, 0, m, &cVar_O9yOlrcC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MSUL8rne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_inVAurtp, 1, m, &cVar_inVAurtp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sfkoRuFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dCnfEdV4, HV_BINOP_MULTIPLY, 0, m, &cBinop_dCnfEdV4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1Wowgf1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FFsOIPvb, HV_BINOP_MULTIPLY, 0, m, &cBinop_FFsOIPvb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MbxNL5rq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e0hUK6oa, HV_BINOP_MULTIPLY, 0, m, &cBinop_e0hUK6oa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tdKtNGqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C22fROfb, HV_BINOP_MULTIPLY, 0, m, &cBinop_C22fROfb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dfatyEm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_PVlP3D21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rbMWmofp, HV_BINOP_MULTIPLY, 0, m, &cBinop_rbMWmofp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wklYDiXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WHD4fa6Z, 0, m, &cVar_WHD4fa6Z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LJJPGxpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_inVAurtp, 0, m, &cVar_inVAurtp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VJlDNA3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mShKJJOU, 1, m, &cIf_mShKJJOU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_rUXhyErJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0U8nt119, m);
}

void Heavy_WSTD_3Q::cBinop_ZrlP2U1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rUXhyErJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_GTEFrM5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mShKJJOU, 0, m, &cIf_mShKJJOU_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_ToDmNY2I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nvo0mJ6i, 0, m, &cSlice_nvo0mJ6i_sendMessage);
      break;
    }
    default: {
      cSwitchcase_epuGxIr9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_nvo0mJ6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4WFzjevz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4WFzjevz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_iJHitIXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4WFzjevz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_4WFzjevz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aKdoaAEH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_89Xj94Bv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_PvGdT9JH_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_fsMEcMeN, 0, m, &cIf_fsMEcMeN_sendMessage);
}

void Heavy_WSTD_3Q::cIf_fsMEcMeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TRVKTAjT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_wQpXqkKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_RawPrfAh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_aO0utE3W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_qiXk7UwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HglamV2M, HV_BINOP_POW, 0, m, &cBinop_HglamV2M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HglamV2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2W3vYrC2, 0, m, &cIf_2W3vYrC2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GUhihSG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_lOPTZWEo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mbRDwISB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rbXxx2M0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_984KO885_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wQpXqkKJ, 0, m, &cIf_wQpXqkKJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rbXxx2M0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wQpXqkKJ, 1, m, &cIf_wQpXqkKJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aO0utE3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GUhihSG5_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_RawPrfAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_2W3vYrC2, 0, m, &cIf_2W3vYrC2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lOPTZWEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HglamV2M, HV_BINOP_POW, 1, m, &cBinop_HglamV2M_sendMessage);
  cMsg_qiXk7UwP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_2W3vYrC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_fR7uKXku, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_PvGdT9JH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fsMEcMeN, 1, m, &cIf_fsMEcMeN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TRVKTAjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TffqUw72, HV_BINOP_GREATER_THAN, 1, m, &cBinop_TffqUw72_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dyg1lYyV, HV_BINOP_EQ, 1, m, &cBinop_Dyg1lYyV_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Ud1TEoWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_h2ZtNq3o, HV_BINOP_ADD, 0, m, &cBinop_h2ZtNq3o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_h2ZtNq3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mbRDwISB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_984KO885_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TffqUw72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2W3vYrC2, 1, m, &cIf_2W3vYrC2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Dyg1lYyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mYGvWqc9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_mYGvWqc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fR7uKXku, m);
}

void Heavy_WSTD_3Q::cCast_SEfvtnfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ud1TEoWP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_TxiuwxBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_89Xj94Bv, 0, m, &cVar_89Xj94Bv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SAXEBfLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h2ZtNq3o, HV_BINOP_ADD, 1, m, &cBinop_h2ZtNq3o_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TffqUw72, HV_BINOP_GREATER_THAN, 0, m, &cBinop_TffqUw72_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dyg1lYyV, HV_BINOP_EQ, 0, m, &cBinop_Dyg1lYyV_sendMessage);
}

void Heavy_WSTD_3Q::cVar_XP5dB4JO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gkLv4ho4_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_IRYxARRK, 0, m, &cIf_IRYxARRK_sendMessage);
}

void Heavy_WSTD_3Q::cIf_IRYxARRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_R3aAbFRa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_YpMz1zFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_DfrkAu5X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_FC8AwZzT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_rf0lH9Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_B82fxOVw, HV_BINOP_POW, 0, m, &cBinop_B82fxOVw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_B82fxOVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TQJF6Sv2, 0, m, &cIf_TQJF6Sv2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PjaesPYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_gzB2Gg1K_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yEU1yEHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_plRpTxzK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_26rzFuQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YpMz1zFf, 0, m, &cIf_YpMz1zFf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_plRpTxzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YpMz1zFf, 1, m, &cIf_YpMz1zFf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FC8AwZzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_PjaesPYx_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_DfrkAu5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_TQJF6Sv2, 0, m, &cIf_TQJF6Sv2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gzB2Gg1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B82fxOVw, HV_BINOP_POW, 1, m, &cBinop_B82fxOVw_sendMessage);
  cMsg_rf0lH9Us_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_TQJF6Sv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VtMHzf4v_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BhuyseUr_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_SShW6jeI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_gkLv4ho4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IRYxARRK, 1, m, &cIf_IRYxARRK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_R3aAbFRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xWfdlT2Z, HV_BINOP_GREATER_THAN, 1, m, &cBinop_xWfdlT2Z_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_17eid4Hl, HV_BINOP_EQ, 1, m, &cBinop_17eid4Hl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8Rx0t5Yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A3hsjseo, HV_BINOP_ADD, 0, m, &cBinop_A3hsjseo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_A3hsjseo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yEU1yEHP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_26rzFuQx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xWfdlT2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TQJF6Sv2, 1, m, &cIf_TQJF6Sv2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_17eid4Hl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TgFBYtSC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_TgFBYtSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VtMHzf4v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BhuyseUr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_SShW6jeI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FByDdFjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A3hsjseo, HV_BINOP_ADD, 1, m, &cBinop_A3hsjseo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xWfdlT2Z, HV_BINOP_GREATER_THAN, 0, m, &cBinop_xWfdlT2Z_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_17eid4Hl, HV_BINOP_EQ, 0, m, &cBinop_17eid4Hl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BtktRHoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XP5dB4JO, 0, m, &cVar_XP5dB4JO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MR7utkz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8Rx0t5Yz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_sRNwaEk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Lbavcuyw_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_trEeQMO4, 0, m, &cIf_trEeQMO4_sendMessage);
}

void Heavy_WSTD_3Q::cIf_trEeQMO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_R4xxMhTo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_HIRUoQN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_SDKfyaUV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1U01TCi1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_c06I3aSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qD2K8oDg, HV_BINOP_POW, 0, m, &cBinop_qD2K8oDg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qD2K8oDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_21vPJTZ1, 0, m, &cIf_21vPJTZ1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eryMfNXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_4ROX5Tg4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gfXHiyLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9x1DVkap_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mXUBR1Xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HIRUoQN1, 0, m, &cIf_HIRUoQN1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9x1DVkap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HIRUoQN1, 1, m, &cIf_HIRUoQN1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1U01TCi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_eryMfNXf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_SDKfyaUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_21vPJTZ1, 0, m, &cIf_21vPJTZ1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4ROX5Tg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qD2K8oDg, HV_BINOP_POW, 1, m, &cBinop_qD2K8oDg_sendMessage);
  cMsg_c06I3aSR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_21vPJTZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_JV3esKSG, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_Lbavcuyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_trEeQMO4, 1, m, &cIf_trEeQMO4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_R4xxMhTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vfxlN3lS, HV_BINOP_GREATER_THAN, 1, m, &cBinop_vfxlN3lS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mNIyDyHh, HV_BINOP_EQ, 1, m, &cBinop_mNIyDyHh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_jzsw7v5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fqxjQnV0, HV_BINOP_ADD, 0, m, &cBinop_fqxjQnV0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fqxjQnV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gfXHiyLl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mXUBR1Xo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vfxlN3lS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_21vPJTZ1, 1, m, &cIf_21vPJTZ1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mNIyDyHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lKHkR8eD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_lKHkR8eD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_JV3esKSG, m);
}

void Heavy_WSTD_3Q::cCast_0TUhLMtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sRNwaEk8, 0, m, &cVar_sRNwaEk8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5o8fljzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fqxjQnV0, HV_BINOP_ADD, 1, m, &cBinop_fqxjQnV0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vfxlN3lS, HV_BINOP_GREATER_THAN, 0, m, &cBinop_vfxlN3lS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mNIyDyHh, HV_BINOP_EQ, 0, m, &cBinop_mNIyDyHh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Dx3yCZF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jzsw7v5x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_PdL6L7wD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_E8fIsxv0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_jzVs62Gu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FLlOfTNG, 0, m, &cSlice_FLlOfTNG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8Os03la4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_FLlOfTNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PmXz83Hp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PmXz83Hp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_9N6OkI9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PmXz83Hp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_PmXz83Hp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6FmlyAVu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_8Os03la4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IUzvHzKm, 0, m, &cSlice_IUzvHzKm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ToDmNY2I_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_IUzvHzKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_keMOmQPQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_keMOmQPQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_OtJgpkga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_keMOmQPQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_keMOmQPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_biDLiiWp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_epuGxIr9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yysvLT5u, 0, m, &cSlice_yysvLT5u_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fxVEE7vV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_yysvLT5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QqXM1GEq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QqXM1GEq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_oMiSmdKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QqXM1GEq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_QqXM1GEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R0h0NINL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_fxVEE7vV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QNdLL6qG, 0, m, &cSlice_QNdLL6qG_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_QNdLL6qG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RxJMErOv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RxJMErOv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_4z0uDaNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RxJMErOv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_RxJMErOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TttfiG15_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_5J4Ra0Q0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kZjIo213, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_K1LV68MA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j72hrAf6, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_bFnfShv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IjAwriQ8, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_2G8HrwJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pIyTGL3T, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ei23RL5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UH8WPBZy, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_a3xpfJYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zTIQJHfI_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_zTIQJHfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yuImlq83, HV_BINOP_DIVIDE, 1, m, &cBinop_yuImlq83_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LHGJHghk_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_aqtwHwhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_SNaDefES_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_MBcUFruy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_aqtwHwhK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SNaDefES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yuImlq83, HV_BINOP_DIVIDE, 0, m, &cBinop_yuImlq83_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LHGJHghk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MBcUFruy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_yuImlq83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dSE6kqam, HV_BINOP_MULTIPLY, 1, m, &cBinop_dSE6kqam_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dSE6kqam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m41fY14I_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8PrJSbHQ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_qmoiLoGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tsZEstK5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_CKDQoD4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ah1dYt5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LrlaHwn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_SkdfuOZU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SkdfuOZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dSE6kqam, HV_BINOP_MULTIPLY, 0, m, &cBinop_dSE6kqam_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9iS1WYvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_g3n4kQHn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_g3n4kQHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U6pGUqmC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_iPLjHGjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ci22RsRA, 1, m, &cVar_Ci22RsRA_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Ci22RsRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_guEZiTTB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Jx1ezR1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSZoWdZ4, HV_BINOP_MULTIPLY, 1, m, &cBinop_sSZoWdZ4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_88M2v7lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Jx1ezR1o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cAqef765_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_uHLyPF9Z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uHLyPF9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mIXYmlTX, HV_BINOP_MULTIPLY, 1, m, &cBinop_mIXYmlTX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_X9ozRlw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iemFMUbP, HV_BINOP_MULTIPLY, 1, m, &cBinop_iemFMUbP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IACcJAJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_X9ozRlw2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7tN1LSPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vheTn3L7, HV_BINOP_MULTIPLY, 1, m, &cBinop_vheTn3L7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_gmRVHMF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9eRtc4px_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9eRtc4px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1N3GXM6F, HV_BINOP_MULTIPLY, 1, m, &cBinop_1N3GXM6F_sendMessage);
}

void Heavy_WSTD_3Q::cVar_nzHbJGEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RlQIWQNv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_LrlaHwn2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dWlvSYKc_sendMessage);
}

void Heavy_WSTD_3Q::cVar_m7gdqJjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9iS1WYvv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8PrJSbHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_CKDQoD4n_sendMessage);
}

void Heavy_WSTD_3Q::cCast_m41fY14I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qmoiLoGG_sendMessage);
}

void Heavy_WSTD_3Q::cSend_tsZEstK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3m7rg6PY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ah1dYt5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_seukyCPo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ZFjuZrt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kPAoGltt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_U6pGUqmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AixIV9ww_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AixIV9ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a2xTOvVl, HV_BINOP_MULTIPLY, 1, m, &cBinop_a2xTOvVl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a2xTOvVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sSmT9LL8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sSmT9LL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZFjuZrt8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_guEZiTTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bw2937zq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bw2937zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vgZlaFmE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yIc2f8mD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qBAFVwVs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_33IjcwRi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RAP2x25X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w0fjWkSX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sSZoWdZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5J4Ra0Q0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_mIXYmlTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K1LV68MA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_iemFMUbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bFnfShv3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vheTn3L7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2G8HrwJF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1N3GXM6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ei23RL5R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_0kWhHQFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nzHbJGEY, 0, m, &cVar_nzHbJGEY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2bE4xjYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m7gdqJjz, 1, m, &cVar_m7gdqJjz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yIc2f8mD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1N3GXM6F, HV_BINOP_MULTIPLY, 0, m, &cBinop_1N3GXM6F_sendMessage);
}

void Heavy_WSTD_3Q::cCast_w0fjWkSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSZoWdZ4, HV_BINOP_MULTIPLY, 0, m, &cBinop_sSZoWdZ4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vgZlaFmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_RAP2x25X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mIXYmlTX, HV_BINOP_MULTIPLY, 0, m, &cBinop_mIXYmlTX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qBAFVwVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vheTn3L7, HV_BINOP_MULTIPLY, 0, m, &cBinop_vheTn3L7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_33IjcwRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iemFMUbP, HV_BINOP_MULTIPLY, 0, m, &cBinop_iemFMUbP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dWlvSYKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ci22RsRA, 0, m, &cVar_Ci22RsRA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RlQIWQNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m7gdqJjz, 0, m, &cVar_m7gdqJjz_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_xEQKIEUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_duuyj0N7, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Xs7s9EY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3XIEhzcA, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_7XEDrN3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PnTbt9HP, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_9MAYT9O7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SEf7LQjZ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_im8M772F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lSQMG6hW_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_lSQMG6hW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Qx4HmoG, HV_BINOP_DIVIDE, 1, m, &cBinop_6Qx4HmoG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jwiQkna0_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_pHz0K2HR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_tbsENdp5_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_vblKZmzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_pHz0K2HR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tbsENdp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Qx4HmoG, HV_BINOP_DIVIDE, 0, m, &cBinop_6Qx4HmoG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jwiQkna0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vblKZmzT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6Qx4HmoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ir6jeCcz, HV_BINOP_MULTIPLY, 1, m, &cBinop_ir6jeCcz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ir6jeCcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4wIpcnkE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j3S9IUvd_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_y4iZDula_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_l8uBa0Hi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_RwD9AStO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_91RJ6KdK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_BXIdmGfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ORnglLhX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ORnglLhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ir6jeCcz, HV_BINOP_MULTIPLY, 0, m, &cBinop_ir6jeCcz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Zy1L7bOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_2aj3nB15_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2aj3nB15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DZa36juY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ej2oz1IH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hq4kKqSH, HV_BINOP_MULTIPLY, 1, m, &cBinop_hq4kKqSH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EGsEEOEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XYVXuw4x, 1, m, &cVar_XYVXuw4x_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YzfOxbDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BCr3AiLl, HV_BINOP_MULTIPLY, 1, m, &cBinop_BCr3AiLl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_meoIdbai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YP8EDmby_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YP8EDmby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GnqC0Ke5, HV_BINOP_MULTIPLY, 1, m, &cBinop_GnqC0Ke5_sendMessage);
}

void Heavy_WSTD_3Q::cVar_XYVXuw4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O5Ljg4Zy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_THBfYb0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O5ML5jUh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_BXIdmGfI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T4DzkvLE_sendMessage);
}

void Heavy_WSTD_3Q::cVar_DAl9UZPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Zy1L7bOS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4wIpcnkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_y4iZDula_sendMessage);
}

void Heavy_WSTD_3Q::cCast_j3S9IUvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_RwD9AStO_sendMessage);
}

void Heavy_WSTD_3Q::cSend_l8uBa0Hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_81NCZFP6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_91RJ6KdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SRcJY6eB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_HZEh7iO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZCgDDWBZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_DZa36juY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_G9b01Wf0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_G9b01Wf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dTY9Vl77, HV_BINOP_MULTIPLY, 1, m, &cBinop_dTY9Vl77_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dTY9Vl77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dZ1OCSex_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dZ1OCSex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HZEh7iO6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_O5Ljg4Zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1AQdp1YH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1AQdp1YH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ttaq0Hhe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y0xlA8X5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qWIayuSK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UKRbHP7F_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z1enPKWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xEQKIEUY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_hq4kKqSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xs7s9EY8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_BCr3AiLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7XEDrN3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_GnqC0Ke5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9MAYT9O7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_C2xQsBZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_THBfYb0x, 0, m, &cVar_THBfYb0x_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WJw2DSye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DAl9UZPl, 1, m, &cVar_DAl9UZPl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_T4DzkvLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XYVXuw4x, 0, m, &cVar_XYVXuw4x_sendMessage);
}

void Heavy_WSTD_3Q::cCast_O5ML5jUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DAl9UZPl, 0, m, &cVar_DAl9UZPl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UKRbHP7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z1enPKWu, HV_BINOP_MULTIPLY, 0, m, &cBinop_z1enPKWu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ttaq0Hhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GnqC0Ke5, HV_BINOP_MULTIPLY, 0, m, &cBinop_GnqC0Ke5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qWIayuSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hq4kKqSH, HV_BINOP_MULTIPLY, 0, m, &cBinop_hq4kKqSH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_y0xlA8X5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BCr3AiLl, HV_BINOP_MULTIPLY, 0, m, &cBinop_BCr3AiLl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_IJAjYs4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nkTlH7mu, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_pYadgbQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KH0KJZJb, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_VMz19Qbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zAnt6Y21, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ENp9fgiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C89W0Wa5, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Kx2fSJnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4tAFxdz2, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_8sSGg4m5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5GT5p3U4_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_5GT5p3U4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iGveYkW0, HV_BINOP_DIVIDE, 1, m, &cBinop_iGveYkW0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R0aegpsO_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_m2njlHik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_dvZiNrTY_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_AEbmaImz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_m2njlHik_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dvZiNrTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iGveYkW0, HV_BINOP_DIVIDE, 0, m, &cBinop_iGveYkW0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_R0aegpsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AEbmaImz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_iGveYkW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pfC6Mgtz, HV_BINOP_MULTIPLY, 1, m, &cBinop_pfC6Mgtz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pfC6Mgtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BLcZdFRE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1FsSvmhb_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_7WxnV9l0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_N6sewsO9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_BthxfAQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M3zUZBem_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_OwmJkI1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_atxow3iQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_atxow3iQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pfC6Mgtz, HV_BINOP_MULTIPLY, 0, m, &cBinop_pfC6Mgtz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nEOCARdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_wnX6hHw8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wnX6hHw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ekdFOFeq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1VjtgnOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CcB4WaOT, HV_BINOP_MULTIPLY, 1, m, &cBinop_CcB4WaOT_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ohH0VTJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7OOqxfWw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7OOqxfWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1VjtgnOV_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_fvpuRkeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_W2zwlbgy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_W2zwlbgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ViRWhzIY, HV_BINOP_MULTIPLY, 1, m, &cBinop_ViRWhzIY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EFfzkep6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U1qQMczF, HV_BINOP_MULTIPLY, 1, m, &cBinop_U1qQMczF_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_YGzEAcKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7Od3Nvv4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7Od3Nvv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EFfzkep6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iPZ8pFp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wGp2aYHf, 1, m, &cVar_wGp2aYHf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_b726G2tG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jjXhYD5c, HV_BINOP_MULTIPLY, 1, m, &cBinop_jjXhYD5c_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_6TqSgxKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ytSDx5Pj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ytSDx5Pj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Syct2vKt, HV_BINOP_MULTIPLY, 1, m, &cBinop_Syct2vKt_sendMessage);
}

void Heavy_WSTD_3Q::cVar_wGp2aYHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SgnFs4oW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_d0mBrJ3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ftVicqAA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_OwmJkI1p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6SdzBqCZ_sendMessage);
}

void Heavy_WSTD_3Q::cVar_tS9Qpmdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_nEOCARdB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BLcZdFRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_7WxnV9l0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1FsSvmhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_BthxfAQP_sendMessage);
}

void Heavy_WSTD_3Q::cSend_N6sewsO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JsLqT4Uh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_M3zUZBem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2qpmpWfN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_qqC8bByD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YB3PnFIL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ekdFOFeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IzCCv2l2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IzCCv2l2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NFGyI3C5, HV_BINOP_MULTIPLY, 1, m, &cBinop_NFGyI3C5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NFGyI3C5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eD79EJgC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eD79EJgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qqC8bByD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_SgnFs4oW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_An7l9Jy3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_An7l9Jy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3GT6A5gO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y5Z9omHe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XsLvq5Oi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yRl6MSKp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QmgEr5MI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s1BDlfJZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CcB4WaOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IJAjYs4e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ViRWhzIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pYadgbQ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_U1qQMczF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VMz19Qbi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jjXhYD5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ENp9fgiR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Syct2vKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kx2fSJnW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_UEAiuB1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d0mBrJ3N, 0, m, &cVar_d0mBrJ3N_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fnoTnedl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tS9Qpmdc, 1, m, &cVar_tS9Qpmdc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XsLvq5Oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jjXhYD5c, HV_BINOP_MULTIPLY, 0, m, &cBinop_jjXhYD5c_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3GT6A5gO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_s1BDlfJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CcB4WaOT, HV_BINOP_MULTIPLY, 0, m, &cBinop_CcB4WaOT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QmgEr5MI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ViRWhzIY, HV_BINOP_MULTIPLY, 0, m, &cBinop_ViRWhzIY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Y5Z9omHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Syct2vKt, HV_BINOP_MULTIPLY, 0, m, &cBinop_Syct2vKt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yRl6MSKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U1qQMczF, HV_BINOP_MULTIPLY, 0, m, &cBinop_U1qQMczF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6SdzBqCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wGp2aYHf, 0, m, &cVar_wGp2aYHf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ftVicqAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tS9Qpmdc, 0, m, &cVar_tS9Qpmdc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VtMHzf4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PdL6L7wD, 1, m, &cIf_PdL6L7wD_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_WOVQ8cal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_E8fIsxv0, m);
}

void Heavy_WSTD_3Q::cBinop_BhuyseUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WOVQ8cal_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SShW6jeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PdL6L7wD, 0, m, &cIf_PdL6L7wD_sendMessage);
}

void Heavy_WSTD_3Q::cVar_WPa3JV8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QRguQUQj, HV_BINOP_DIVIDE, 0, m, &cBinop_QRguQUQj_sendMessage);
}

void Heavy_WSTD_3Q::cVar_N4tSbeiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xhGgIH0b, HV_BINOP_DIVIDE, 1, m, &cBinop_xhGgIH0b_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QRguQUQj, HV_BINOP_DIVIDE, 1, m, &cBinop_QRguQUQj_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_rzGpvlUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dFWl0Vvy, HV_BINOP_DIVIDE, 0, m, &cBinop_dFWl0Vvy_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_gt6xM4V8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dFWl0Vvy, HV_BINOP_DIVIDE, 1, m, &cBinop_dFWl0Vvy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_IZ9kyi5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WPa3JV8v, 0, m, &cVar_WPa3JV8v_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7ZYvvrC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N4tSbeiN, 0, m, &cVar_N4tSbeiN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qEXXPTnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xhGgIH0b, HV_BINOP_DIVIDE, 0, m, &cBinop_xhGgIH0b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xhGgIH0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_rzGpvlUQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QRguQUQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_gt6xM4V8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dFWl0Vvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_2Ss1L7V1_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_9vPibqIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_SKDLDmL4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LMc4OugC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_EtBrhKAr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2Ss1L7V1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LMc4OugC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EtBrhKAr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_9vPibqIO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SKDLDmL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vLYvvqaf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_KrjsgUyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1c16vHKj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_jzVs62Gu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Ccm48n17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1c16vHKj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_jzVs62Gu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_SlyoB26v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1c16vHKj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_jzVs62Gu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_lhS5sZuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1c16vHKj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_jzVs62Gu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vLYvvqaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_1c16vHKj_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_jzVs62Gu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_w9iwripA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_SwEErfxM, 0, m, &cVar_SwEErfxM_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9wLSzhVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_tK2MQf97, 0, m, &cVar_tK2MQf97_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_m16UbkiZ, 0, m, &cVar_m16UbkiZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Vr9aljDN, 0, m, &cVar_Vr9aljDN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ASc99Wet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tK2MQf97, 0, m, &cVar_tK2MQf97_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_DGhw8SBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m16UbkiZ, 0, m, &cVar_m16UbkiZ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_MrpvwYBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Vr9aljDN, 0, m, &cVar_Vr9aljDN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_onvAC7Hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5Dk7Jf5n, 0, m, &cVar_5Dk7Jf5n_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_iwA1XD8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hba0s3NV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Iw7wm7eT_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3eDnSN55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svjvm15W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qBsLuEsQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0JBEEr15_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_fV6DJCOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7weiZPK3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vhiEWnr7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GT4yewcJ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ftUfc8GP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dFCGQ0dR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rv8RTwib_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QzOildlU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_X3bgaxio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G6bM6WsN_sendMessage(_c, 0, m);
  cMsg_UHHbUTPN_sendMessage(_c, 0, m);
  cMsg_Ag5WbowL_sendMessage(_c, 0, m);
  cMsg_a3xpfJYP_sendMessage(_c, 0, m);
  cMsg_im8M772F_sendMessage(_c, 0, m);
  cMsg_8sSGg4m5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jKsW4pVi, 0, m, &cVar_jKsW4pVi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5Dk7Jf5n, 0, m, &cVar_5Dk7Jf5n_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_O9yOlrcC, 0, m, &cVar_O9yOlrcC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nzHbJGEY, 0, m, &cVar_nzHbJGEY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_THBfYb0x, 0, m, &cVar_THBfYb0x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_d0mBrJ3N, 0, m, &cVar_d0mBrJ3N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JJ3omtDP, 0, m, &cVar_JJ3omtDP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o1kr1i2D, 0, m, &cVar_o1kr1i2D_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JcnpS2yf, 0, m, &cVar_JcnpS2yf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fP4bpw4b, 0, m, &cVar_fP4bpw4b_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zeskSoJL, 0, m, &cVar_zeskSoJL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_280zKExu, 0, m, &cVar_280zKExu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UDhhkaJT, 0, m, &cVar_UDhhkaJT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CQpjVNNW, 0, m, &cVar_CQpjVNNW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iJHitIXB, 0, m, &cVar_iJHitIXB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_89Xj94Bv, 0, m, &cVar_89Xj94Bv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XP5dB4JO, 0, m, &cVar_XP5dB4JO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sRNwaEk8, 0, m, &cVar_sRNwaEk8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9N6OkI9I, 0, m, &cVar_9N6OkI9I_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OtJgpkga, 0, m, &cVar_OtJgpkga_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oMiSmdKG, 0, m, &cVar_oMiSmdKG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4z0uDaNC, 0, m, &cVar_4z0uDaNC_sendMessage);
  cMsg_9wLSzhVd_sendMessage(_c, 0, m);
  cMsg_w9iwripA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_4WDzG9Q7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PRMYv0s2, HV_BINOP_MULTIPLY, 0, m, &cBinop_PRMYv0s2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZNrqOr5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EsIxlgZI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_vtIkOesH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ox9i09yV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Ba046dJS_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZW26pAqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3nj8mCKC_sendMessage);
  cMsg_HMIeqZSp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_U1do5K8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yF9ODYAM, HV_BINOP_MULTIPLY, 0, m, &cBinop_yF9ODYAM_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_xCsbnVhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_c3RW78rM_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_bmRTsSt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V57AtSvS, HV_BINOP_MULTIPLY, 1, m, &cBinop_V57AtSvS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MvQZsE3j_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HXrWhtHH_sendMessage);
  cMsg_TCsGDltG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_MsqV6TGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XEVProeF, HV_BINOP_MULTIPLY, 0, m, &cBinop_XEVProeF_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_np1xhTq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_msWhHJcg_sendMessage(_c, 0, m);
  cMsg_BjifunOR_sendMessage(_c, 0, m);
  cMsg_NpRT4Oni_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_gEqWLPTh_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_GI5QpUsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fDd62fW0_sendMessage);
  cMsg_cOUpU7KD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_aKdoaAEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_THBfYb0x, 0, m, &cVar_THBfYb0x_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_TttfiG15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WJw2DSye_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C2xQsBZu_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_6FmlyAVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TxiuwxBr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SAXEBfLb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SEfvtnfB_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_R0h0NINL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0TUhLMtn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5o8fljzL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Dx3yCZF0_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_biDLiiWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BtktRHoh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FByDdFjm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MR7utkz3_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3m7rg6PY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a2xTOvVl, HV_BINOP_MULTIPLY, 0, m, &cBinop_a2xTOvVl_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_seukyCPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_88M2v7lx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cAqef765_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IACcJAJl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_7tN1LSPH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_kPAoGltt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iPLjHGjV_sendMessage);
  cMsg_gmRVHMF8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_81NCZFP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dTY9Vl77, HV_BINOP_MULTIPLY, 0, m, &cBinop_dTY9Vl77_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_SRcJY6eB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_YzfOxbDE_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZCgDDWBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z1enPKWu, HV_BINOP_MULTIPLY, 1, m, &cBinop_z1enPKWu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ej2oz1IH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EGsEEOEt_sendMessage);
  cMsg_meoIdbai_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_JsLqT4Uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NFGyI3C5, HV_BINOP_MULTIPLY, 0, m, &cBinop_NFGyI3C5_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_2qpmpWfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ohH0VTJo_sendMessage(_c, 0, m);
  cMsg_fvpuRkeg_sendMessage(_c, 0, m);
  cMsg_YGzEAcKs_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_b726G2tG_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_YB3PnFIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iPZ8pFp7_sendMessage);
  cMsg_6TqSgxKx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_REFpn93v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SwEErfxM, 0, m, &cVar_SwEErfxM_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_PErUpu7o, VOf(Bf0));
    __hv_line_f(&sLine_OYCgfY5B, VOf(Bf1));
    __hv_line_f(&sLine_WP03lwbU, VOf(Bf2));
    __hv_line_f(&sLine_tVqPKjA8, VOf(Bf3));
    __hv_line_f(&sLine_en9kzWB2, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_sgijKl8m, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_u3FYnzD4, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_aoNhaAGT, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_241gE8Y5, VOf(Bf1));
    __hv_line_f(&sLine_I7xPserz, VOf(Bf0));
    __hv_line_f(&sLine_wLm86jBE, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_vkIdo3oW, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_0U8nt119, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_HDcwM5pp, VOf(Bf5));
    __hv_line_f(&sLine_xxpgAHg5, VOf(Bf1));
    __hv_line_f(&sLine_qeV0ph8R, VOf(Bf2));
    __hv_line_f(&sLine_iy83qzck, VOf(Bf4));
    __hv_line_f(&sLine_Z2iwXVA0, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_Pg9bK5mN, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_3S91fDi8, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_kZjIo213, VOf(Bf6));
    __hv_line_f(&sLine_j72hrAf6, VOf(Bf2));
    __hv_line_f(&sLine_IjAwriQ8, VOf(Bf1));
    __hv_line_f(&sLine_pIyTGL3T, VOf(Bf5));
    __hv_line_f(&sLine_UH8WPBZy, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_Y9UKW6gQ, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_fR7uKXku, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_duuyj0N7, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_3XIEhzcA, VOf(Bf2));
    __hv_line_f(&sLine_PnTbt9HP, VOf(Bf6));
    __hv_line_f(&sLine_SEf7LQjZ, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_bTalbYXB, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_E8fIsxv0, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_nkTlH7mu, VOf(Bf8));
    __hv_line_f(&sLine_KH0KJZJb, VOf(Bf2));
    __hv_line_f(&sLine_zAnt6Y21, VOf(Bf1));
    __hv_line_f(&sLine_C89W0Wa5, VOf(Bf7));
    __hv_line_f(&sLine_4tAFxdz2, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_iwzq1l1B, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_JV3esKSG, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
